@@ -26,6 +26,7 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 import mimetypes
 import sys
+from functools import partial
 
 from fringe_utils.utils import Helper 
 
@@ -34,11 +35,13 @@ class GSuite():
         'https://www.googleapis.com/auth/drive',
         'https://www.googleapis.com/auth/drive.file',
         'https://www.googleapis.com/auth/spreadsheets',
-        'https://mail.google.com/'
+        'https://mail.google.com/',
+        'https://www.googleapis.com/auth/presentations'
     ]
 
-    def __init__(self, secrets_path='creds/oauth-creds-gsuite-api.json'):
-        self.secretsPath = secrets_path
+    def __init__(self, secrets_path='../creds/oauth-creds-gsuite-api.json'):
+        dirname = os.path.dirname(__file__)
+        self.secretsPath = os.path.join(dirname, secrets_path)
 
     def connect(self, service='sheets', version='v4', scopes=scopes, 
         pathToCreds=None, pickleName='token'):
@@ -76,7 +79,11 @@ class GSheets():
     test_update_range = 'Sheet1!A20'
 
     def __init__(self, scopes=None, secretsPath=None):
-        self.service = GSuite(secrets_path=secretsPath).connect(scopes=scopes) if scopes else GSuite(secrets_path=secretsPath).connect()
+        gsuite = partial(GSuite)
+        if secretsPath: gsuite = partial(gsuite, secrets_path=secretsPath)
+        gsuite_connect = partial(gsuite().connect)
+        if scopes: gsuite_connect = partial(gsuite_connect, scopes=scopes)
+        self.service = gsuite_connect()
 
     def testGet(self, ssid=test_ssid, range=test_get_range, 
         valueRenderOption=value_render_option[0]):
@@ -202,8 +209,19 @@ class GSheets():
 
 class GSlides():
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, scopes=None, secretsPath=None):
+        gsuite = partial(GSuite)
+        if secretsPath: gsuite = partial(gsuite, secrets_path=secretsPath)
+        gsuite_connect = partial(gsuite().connect, service='slides', version='v1')
+        if scopes: gsuite_connect = partial(gsuite_connect, scopes=scopes)
+        self.service = gsuite_connect()
+        self.__helper = Helper()
+    
+    def test_enumerate_slides(self, slides_id):
+        presentation = self.service.presentations().get(presentationId = slides_id).execute()
+        slides = presentation.get('slides')
+        for i, slide in enumerate(slides):
+            print('- Slide #{} contains {} elements.'.format(i + 1, len(slide.get('pageElements'))))
 
 class GContacts():
     
@@ -216,8 +234,11 @@ class GMail():
     messageListVisibilities = ['hide', 'show']
 
     def __init__(self, scopes=None, secretsPath=None):
-        self.service = GSuite(secrets_path=secretsPath).connect(scopes=scopes, service='gmail', version='v1') \
-            if scopes else GSuite(secrets_path=secretsPath).connect(service='gmail', version='v1')
+        gsuite = partial(GSuite)
+        if secretsPath: gsuite = partial(gsuite, secrets_path=secretsPath)
+        gsuite_connect = partial(gsuite().connect, service='gmail', version='v1')
+        if scopes: gsuite_connect = partial(gsuite_connect, scopes=scopes)
+        self.service = gsuite_connect()
         self.__helper = Helper()
     
     def buildGmailSearchQuery(self, searchTerm, subject=None, label=None, hasAttachment=False):
@@ -381,8 +402,11 @@ class GDrive():
     apiDocs = 'https://developers.google.com/drive/api/v3/reference'
 
     def __init__(self, scopes=None, secretsPath=None):
-        self.service = GSuite(secrets_path=secretsPath).connect(service='drive', version='v3', scopes=scopes) \
-            if scopes else GSuite(secrets_path=secretsPath).connect(service='drive', version='v3')
+        gsuite = partial(GSuite)
+        if secretsPath: gsuite = partial(gsuite, secrets_path=secretsPath)
+        gsuite_connect = partial(gsuite().connect, service='drive', version='v3')
+        if scopes: gsuite_connect = partial(gsuite_connect, scopes=scopes)
+        self.service = gsuite_connect()
 
     def moveFile(self, id, newFolderId):
         file = self.service.files().get(fileId = id, fields = 'parents').execute()
@@ -410,6 +434,16 @@ class GDrive():
             fields = 'id'
         ).execute()
         return file.get('id')
+    
+    def createGDriveFolder(folderPrefix, parentID=None):
+        # Create a folder in Drive, returns the newely created folders ID
+        # Then create a spreadsheet in that folder
+        folder_metadata = {
+            'name': folderPrefix,
+            'mimeType': 'application/vnd.google-apps.folder'
+        }
+        if parentID:
+            folder_metadata['parents'] = [{'id': parentID}]
 
 class BigQuery():
     apiDocs = [
